package App::colgrep ;  
our $VERSION = '0.100' ; 
our $DATE = '2021-06-07T02:12+09:00' ; 

=encoding utf8

=head1 NAME

App::colgrep

=head1 SYNOPSIS

This module provides a Unix-like command `F<colgrep>'. 
This commad will "grep" along a specified column over all the row of a given file,
and every (the whole) row which is hit by that "grep" will be output.


=head1 DESCRIPTION



=head1 SEE ALSO


=cut

1 ;
